const path = require('path')
const { CleanWebpackPlugin } = require('clean-webpack-plugin')
const MiniCssExtractPlugin = require('mini-css-extract-plugin')
const VueLoaderPlugin = require('vue-loader/lib/plugin')
const CopyWebpackPlugin = require("copy-webpack-plugin")

function resolve(dir) {
  return path.join(__dirname, '..', dir)
}

const devMod = process.env.NODE_ENV === "development"

module.exports = {
  entry: {
    main: './src/main.js'
  },
  output: {
    path: path.resolve(__dirname, '../dist'),
    filename: devMod ? '[name].bundle.js' : '[name].[contenthash].js'
  },
  module: {
    rules: [
      {
        test: /\.vue$/,
        loader: 'vue-loader'
      },
      {
        test: /\.m?js$/,
        include: [
          resolve('src'),
          resolve('node_modules/ripples-core/src'),
          resolve('node_modules/ripples-psc/src'),
          resolve('node_modules/ripples-psc/node_modules/ripples-core/src'), // 解决服务器上打包报错，本地win下打包无此问题
          resolve('node_modules/ems-components/src'),
        ],
        // exclude: file => (
        //   /node_modules/.test(file) &&
        //   !/\.vue\.js/.test(file)
        // ),
        use: {
          loader: "babel-loader",
          options: {
            presets: [
              '@vue/babel-preset-jsx',
              [
                '@babel/preset-env',
                {
                  'modules': false,
                  'useBuiltIns': 'entry',
                  'corejs': 3
                }
              ]
            ],
            plugins: [
              '@babel/plugin-transform-runtime',
              [
                "component",
                {
                  "libraryName": "element-ui",
                  "styleLibraryName": "theme-chalk"
                }
              ]
            ]
          }
        }
      },
      {
        test: /\.less$/,
        use: [
          {
            loader: devMod ? 'vue-style-loader' : MiniCssExtractPlugin.loader,
            options: {
              hmr: devMod,
              reloadAll: true
            },
          },
          'css-loader',
          {
            loader: 'postcss-loader',
            options: {
              ident: 'postcss',
              plugins: [
                require('autoprefixer')()
              ]
            }
          },
          'less-loader'
        ]
      },
      {
        test: /\.css$/,
        use: [
          {
            loader: devMod ? 'vue-style-loader' : MiniCssExtractPlugin.loader,
            options: {
              hmr: devMod,
              reloadAll: true
            },
          },
          'css-loader',
          {
            loader: 'postcss-loader',
            options: {
              ident: 'postcss',
              plugins: [
                require('autoprefixer')()
              ]
            }
          },

        ]
      },
      {
        test: /\.(gif|jpg|png|woff|svg|eot|ttf)\??.*$/,
        use: ["file-loader"]
      },

    ]
  },
  plugins: [
    new CleanWebpackPlugin(),
    new MiniCssExtractPlugin({
      filename: devMod ? '[name].css' : '[name].[hash].css',
      chunkFilename: devMod ? '[id].css' : '[id].[hash].css'
    }),
    new VueLoaderPlugin(),
    new CopyWebpackPlugin([
      { from: 'static', to: '' }
    ])
  ],
  resolve: {
    extensions: ['.js', '.vue'],
    alias: {
      'vue': 'vue/dist/vue.esm.js',
      "@": resolve('src'),
      '@static': resolve('static'),
      '@root': resolve('/'),
      'ems-admin@': resolve('src')
    }
  }
}