const webpack = require("webpack")
const path = require('path')
const webpackMerge = require('webpack-merge')
const webpackCommonConfig = require('./webpack.base.config.js')
const HtmlWebpackPlugin = require('html-webpack-plugin')
const config = require('./config.json')

module.exports = webpackMerge(webpackCommonConfig, {
  mode: 'development',
  stats: 'minimal',
  devServer: {
    contentBase: false,
    hot: true,
    proxy: {
      '/mams-rest/*': {
        target: 'http://10.0.49.60:7079/mams-service',
        secure: false,
        changeOrigin: true
      },
      '/ems-claim/*': {
        // 开发人员无网关
        // target: 'http://10.52.226.164:7001',
        // pathRewrite: { "^/ems-claim": "" },
        target: 'http://10.0.49.60:7079',
        secure: false,
        changeOrigin: true
      },
      '/ems-base-data/*': {
        target: 'http://10.0.49.60:7079',
        secure: false,
        changeOrigin: true
      },
      '/biz-m-rest/*': {
        target: 'http://10.0.49.60:7079',
        secure: false,
        changeOrigin: true
      },
      '/org-arch-web/*': {
        target: 'http://10.0.49.60:7079',
        secure: false,
        changeOrigin: true
      },
      '/ems-process-service/*': {
        // 开发人员无网关
        // target: 'http://10.52.226.176:9970',
        // pathRewrite: { "^/ems-process-service": "" },

        // 测试环境
        target: 'http://10.0.49.60:7079',
        secure: false,
        changeOrigin: true,

      },
      '/ems-accountant-job-pool/*': {
        // 开发人员无网关
        // target: 'http://10.52.226.22:7003',
        // pathRewrite: { "^/ems-process-service": "" },

        // 测试环境
        target: 'http://10.0.49.60:7079',
        secure: false,
        changeOrigin: true,

      },
      '/ems-payment/*': {
        // 开发人员无网关
        // target: 'http://10.52.226.22:7003',
        // pathRewrite: { "^/ems-process-service": "" },

        // 测试环境
        target: 'http://10.0.49.60:7079',
        secure: false,
        changeOrigin: true,
      },
      '/ems-payment/*': {
        // 开发人员无网关
        // target: 'http://10.52.226.22:7003',
        // pathRewrite: { "^/ems-process-service": "" },

        // 测试环境
        target: 'http://10.0.49.60:7079',
        secure: false,
        changeOrigin: true,
      },
      // 后台管理中心
      '/ems-admin/*': {
        // 开发人员无网关
        // target: 'http://10.54.24.23:7002',
        // pathRewrite: { "^/ems-admin": "" },

        // 测试环境
        target: 'http://10.0.49.60:7079',
        secure: false,
        changeOrigin: true,
      },
      // 预算
      '/ems-budget/*': {
        // 测试环境
        target: 'http://10.0.49.60:7016',
        secure: false,
        changeOrigin: true,
        pathRewrite: { "^/ems-budget": "" },
      },
      '*': {
        target: 'http://10.0.49.60:7079',
        secure: false,
        changeOrigin: true
      },
    }
  },
  plugins: [
    new webpack.NamedModulesPlugin(),
    new webpack.HotModuleReplacementPlugin(),
    new webpack.DefinePlugin({
      'process.env': {
        API: JSON.stringify(config['development'])
      }
    }),
    new HtmlWebpackPlugin({
      title: '财务报账系统',
      chunks: ['main'],
      template: path.resolve(__dirname, '../src/template/index.ejs'),
      hash: true,
      favicon: path.resolve('td_icon.ico')
    }),
  ],
  devtool: 'inline-source-map'
})