const webpack = require("webpack")
const path = require('path')
const webpackMerge = require('webpack-merge')
const webpackCommonConfig = require('./webpack.base.config.js')
const OptimizeCSSAssetsPlugin = require("optimize-css-assets-webpack-plugin")
const TerserWebpackPlugin = require("terser-webpack-plugin")
const HtmlWebpackPlugin = require('html-webpack-plugin')
const config = require('./config.json')

module.exports = function (env) {
  const prodEnv = env.prod
  console.log("-----------------------------------------")
  console.log(`正式运行环境配置：config.json=> ${prodEnv}`)
  console.log("-----------------------------------------")
  return webpackMerge(webpackCommonConfig, {
    mode: 'production',
    stats: 'minimal',
    optimization: {
      minimizer: [
        new TerserWebpackPlugin({
          parallel: true,
          terserOptions: {
            compress: {
              drop_console: true,
              drop_debugger: true
            }
          }
        }),
        new OptimizeCSSAssetsPlugin()
      ],
      runtimeChunk: 'single',
      moduleIds: 'hashed',
      splitChunks: {
        cacheGroups: {
          vendor: {
            test: /[\\/]node_modules[\\/](vue|vuex|vue-router|vue-i18n|iview|miment|element-ui|vuedraggable|crypto-js|extend|axios|clipboard)[\\/]/,
            name: 'vendor',
            chunks: 'all'
          }
        }
      }
    },
    plugins: [
      new webpack.DefinePlugin({
        'process.env': {
          API: JSON.stringify(config[prodEnv])
        }
      }),
      new HtmlWebpackPlugin({
        title: '财务报账系统',
        chunks: ['runtime', 'vendor', 'main'],
        template: path.resolve(__dirname, '../src/template/index.ejs'),
        hash: false,
        favicon: path.resolve('td_icon.ico')
      }),
    ]
  })
}